tonalitytools.ChordClass
========================

.. abjad-lineage:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass

.. autoclass:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.bass
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.cardinality
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.extent
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.figured_bass
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.inversion
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.inversion_equivalent_diatonic_interval_class_vector
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.markup
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.named_chromatic_pitch_classes
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.numbered_chromatic_pitch_class_set
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.quality_indicator
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.quality_pair
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.root
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.root_string
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.copy
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.difference
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.intersection
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.isdisjoint
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.issubset
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.issuperset
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.order_by
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.transpose
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.union
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__and__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__cmp__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__contains__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__hash__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__iter__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__le__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__len__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__or__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__rand__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__ror__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__rsub__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__rxor__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__str__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__sub__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__xor__
   :noindex:
